@@ -21,7 +21,7 @@ convertMlrLearnerToOMLFlow = function(lrn, name = paste0("mlr.", lrn$id), descri
   assertClass(lrn, "Learner")
   assertString(name)
 
-  #lrn = removeDefaultsFromParamValues(lrn)
+  # FIXME: for preproc wrappers not all par.vals are deleted due to a mlr bug, see https://github.com/mlr-org/mlr/issues/2218 . However, this is good for us as the uploaded learner at least contains this info.
   lrn = removeAllHyperPars(lrn)
 
   if (is.null(description))
@@ -134,7 +134,7 @@ removeAllHyperPars = function(lrn) {
 # pars
 makeFlowParameterList = function(lrn) {
   par.list = makeFlowParameterListForMlrLearner(lrn)
-  par.list = append(par.list, makeFlowParameterListFor())
+  par.list = append(par.list, makeFlowParameterListForSeed())
   return(par.list)
 }
 
@@ -157,9 +157,14 @@ makeFlowParameterListForMlrLearner = function(lrn) {
 # @title Helper to create parameters for random numbers generator.
 #
 # @return [list] of OMLFlowParameter objects.
-makeFlowParameterListFor = function() {
+makeFlowParameterListForSeed = function() {
   # now handle random numbers generator seeding
-  seed.pars = setNames(c(1, RNGkind()), c("openml.seed", "openml.kind", "openml.normal.kind"))
+  rng.kind = RNGkind()
+  if (length(rng.kind) == 2)
+    rng.kind = setNames(rng.kind, c("openml.kind", "openml.normal.kind"))
+  if (length(rng.kind) == 3)
+    rng.kind = setNames(rng.kind, c("openml.kind", "openml.normal.kind", "openml.sample.kind"))
+  seed.pars = c("openml.seed" = 1, rng.kind)
   lapply(seq_along(seed.pars), function(x) {
     makeOMLFlowParameter(
       name = names(seed.pars[x]),
@@ -167,15 +172,3 @@ makeFlowParameterListFor = function() {
       default.value = seed.pars[x]
   )})
 }
-
-# removeDefaultsFromParamValues = function(lrn) {
-#   par.defaults = getDefaults(getParamSet(lrn))
-#   par.vals = lrn$par.vals
-#   par.ind = vlapply(names(par.vals), function(x) !isTRUE(all.equal(par.defaults[[x]] , par.vals[[x]])))
-#   lrn$par.vals = par.vals[par.ind]
-#
-#   if (!is.null(lrn$next.learner))
-#     lrn$next.learner = removeDefaultsFromParamValues(lrn$next.learner)
-#
-#   return(lrn)
-# }
